@@ -1,19 +1,7 @@
 /*
- * Copyright (C) 2013 - 2014  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013-2014 Daniel Vrátil <dvratil@redhat.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -23,6 +11,7 @@
 #include "gdrivehelper.h"
 #include "gdriveurl.h"
 #include "gdriveversion.h"
+#include "gdrive_udsentry.h"
 
 #include <QApplication>
 #include <QMimeDatabase>
@@ -170,7 +159,6 @@ void KIOGDrive::fileSystemFreeSpace(const QUrl &url)
             setMetaData(QStringLiteral("total"), QString::number(about->quotaBytesTotal()));
             setMetaData(QStringLiteral("available"), QString::number(about->quotaBytesTotal() - about->quotaBytesUsedAggregate()));
             finished();
-            return;
         }
     }
 }
@@ -236,7 +224,12 @@ KIO::UDSEntry KIOGDrive::fileToUDSEntry(const FilePtr &origFile, const QString &
         entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IWGRP | S_IXGRP | S_IROTH | S_IXOTH);
     }
 
-    entry.fastInsert(KIO::UDSEntry::UDS_EXTRA, file->alternateLink().toString());
+    entry.fastInsert(GDriveUDSEntryExtras::Id, file->id());
+    entry.fastInsert(GDriveUDSEntryExtras::Url, file->alternateLink().toString());
+    entry.fastInsert(GDriveUDSEntryExtras::Version, QString::number(file->version()));
+    entry.fastInsert(GDriveUDSEntryExtras::Md5, file->md5Checksum());
+    entry.fastInsert(GDriveUDSEntryExtras::LastModifyingUser, file->lastModifyingUserName());
+    entry.fastInsert(GDriveUDSEntryExtras::Owners, file->ownerNames().join(QStringLiteral(", ")));
 
     return entry;
 }
@@ -352,7 +345,6 @@ void KIOGDrive::listAccounts()
     listEntry(entry);
 
     finished();
-    return;
 }
 
 void KIOGDrive::listSharedDrivesRoot(const QUrl &url)
@@ -527,7 +519,7 @@ QString KIOGDrive::resolveFileIdFromPath(const QString &path, PathFlags flags)
     Q_ASSERT(!gdriveUrl.isRoot());
 
     if (gdriveUrl.isAccountRoot() || gdriveUrl.isTrashDir()) {
-        qCDebug(GDRIVE) << "Resolved" << path << "to \"root\"";
+        qCDebug(GDRIVE) << "Resolved" << path << "to account root";
         return rootFolderId(gdriveUrl.account());
     }
 
@@ -552,6 +544,8 @@ QString KIOGDrive::resolveFileIdFromPath(const QString &path, PathFlags flags)
         return QString();
     }
 
+    qCDebug(GDRIVE) << "Getting ID for" << gdriveUrl.filename() << "in parent with ID" << parentId;
+
     FileSearchQuery query;
     if (flags != KIOGDrive::None) {
         query.addQuery(FileSearchQuery::MimeType,
@@ -570,7 +564,6 @@ QString KIOGDrive::resolveFileIdFromPath(const QString &path, PathFlags flags)
     }
 
     const ObjectsList objects = fetchJob.items();
-    qCDebug(GDRIVE) << objects;
     if (objects.isEmpty()) {
         qCWarning(GDRIVE) << "Failed to resolve" << path;
         return QString();
@@ -822,7 +815,10 @@ void KIOGDrive::mkdir(const QUrl &url, int permissions)
 
 void KIOGDrive::stat(const QUrl &url)
 {
-    qCDebug(GDRIVE) << "Going to stat()" << url;
+    // TODO We should be using StatDetails to limit how we respond to a stat request
+    // const QString statDetails = metaData(QStringLiteral("statDetails"));
+    // KIO::StatDetails details = statDetails.isEmpty() ? KIO::StatDefaultDetails : static_cast<KIO::StatDetails>(statDetails.toInt());
+    // qCDebug(GDRIVE) << "Going to stat()" << url << "for details" << details;
 
     const auto gdriveUrl = GDriveUrl(url);
     if (gdriveUrl.isRoot()) {
